@@ -2,37 +2,36 @@
 #'
 #' The Ceteris Paribus-majority relation compares the relative success between two players joining a coalition.
 #'
-#' \loadmathjax
-#' Given two elements \mjseqn{i} and \mjseqn{j}, go through each coalition \mjeqn{S \in 2^{N \setminus \lbrace i, j \rbrace}}{S in 2^(N - \{i,j\})}.
-#' \mjeqn{D_{ij}(\succeq)}{D_ij(>=)} then contains all coalitions \mjseqn{S} where
-#' \mjeqn{S \cup \lbrace i \rbrace \succeq S \cup \lbrace j \rbrace}{S u \{i\} >= S u \{j\}} and \mjeqn{D_{ji}(\succeq)}{D_ji(>=)} contains all coalitions where
-#' \mjeqn{S \cup \lbrace j \rbrace \succeq S \cup \lbrace i \rbrace}{S u \{j\} >= S u \{i\}}.
+#' Given two elements \eqn{i}{i} and \eqn{j}{j}, go through each coalition \eqn{S \in 2^{N \setminus \lbrace i, j \rbrace}}{S in 2^(N - \{i,j\})}.
+#' \eqn{D_{ij}(\succeq)}{D_ij(>=)} then contains all coalitions \eqn{S}{S} where
+#' \eqn{S \cup \lbrace i \rbrace \succeq S \cup \lbrace j \rbrace}{S u \{i\} >= S u \{j\}} and \eqn{D_{ji}(\succeq)}{D_ji(>=)} contains all coalitions where
+#' \eqn{S \cup \lbrace j \rbrace \succeq S \cup \lbrace i \rbrace}{S u \{j\} >= S u \{i\}}.
 #'
 #' The cardinalities
-#' \mjeqn{d_{ij}(\succeq) = |D_{ij}|}{d_ij(>=) = |D_ij|} and
-#' \mjeqn{d_{ji}(\succeq) = |D_{ji}|}{d_ij(>=) = |D_ji|} represent the score of the two elements, where
-#' \mjeqn{i \succ j}{i > j}    if \mjeqn{d_{ij}(\succeq)   >  d_{ji}(\succeq)}{d_ij(>=) >  d_ji(>=)} and
-#' \mjeqn{i \sim  j}{i ~ j}    if \mjeqn{d_{ij}(\succeq)  ==  d_{ji}(\succeq)}{d_ij(>=) == d_ji(>=)}.
+#' \eqn{d_{ij}(\succeq) = |D_{ij}|}{d_ij(>=) = |D_ij|} and
+#' \eqn{d_{ji}(\succeq) = |D_{ji}|}{d_ij(>=) = |D_ji|} represent the score of the two elements, where
+#' \eqn{i \succ j}{i > j}    if \eqn{d_{ij}(\succeq)   >  d_{ji}(\succeq)}{d_ij(>=) >  d_ji(>=)} and
+#' \eqn{i \sim  j}{i ~ j}    if \eqn{d_{ij}(\succeq)  ==  d_{ji}(\succeq)}{d_ij(>=) == d_ji(>=)}.
 #'
 #' [`cpMajorityComparison()`] tries to retain all that information. The list returned contains the following information.
-#' Note that in this context the two elements \mjseqn{i} and \mjseqn{j} refer to element 1 and element 2 respectively.
+#' Note that in this context the two elements \eqn{i}{i} and \eqn{j}{j} refer to element 1 and element 2 respectively.
 #'
 #' * `$e1`: list of information about element 1
 #'   * `$e1$name`: name of element 1
-#'   * `$e1$score`: score \mjeqn{d_{ij}(\succeq)}{d_ij(>=)}. \mjeqn{d_{ij}(\succ)}{d_ij(>)} if `strictly == TRUE`
-#'   * `$e1$winningCoalitions`: list of coalition [`sets::set`]s \mjeqn{S \in D_{ij}(\succeq)}{S in D_ij(>=)}. \mjeqn{S \in D_{ij}(\succ)}{S in D_ij(>)} if `strictly == TRUE`
+#'   * `$e1$score`: score \eqn{d_{ij}(\succeq)}{d_ij(>=)}. \eqn{d_{ij}(\succ)}{d_ij(>)} if `strictly == TRUE`
+#'   * `$e1$winningCoalitions`: list of coalition [`vectors`][base::c()] \eqn{S \in D_{ij}(\succeq)}{S in D_ij(>=)}. \eqn{S \in D_{ij}(\succ)}{S in D_ij(>)} if `strictly == TRUE`
 #' * `$e2`: list of information about element 2
 #'   * `$e2$name`: name of element 2
-#'   * `$e1$score`: score \mjeqn{d_{ji}(\succeq)}{d_ji(>=)}. \mjeqn{d_{ji}(\succ)}{d_ji(>)} if `strictly == TRUE`
-#'   * `$e1$winningCoalitions`: list of coalition [`sets::set`]s \mjeqn{S \in D_{ji}(\succeq)}{S in D_ji(>=)}.  \mjeqn{S \in D_{ji}(\succ)}{S in D_ji(>)} if `strictly == TRUE`
+#'   * `$e1$score`: score \eqn{d_{ji}(\succeq)}{d_ji(>=)}. \eqn{d_{ji}(\succ)}{d_ji(>)} if `strictly == TRUE`
+#'   * `$e1$winningCoalitions`: list of coalition [`vectors`][base::c()] \eqn{S \in D_{ji}(\succeq)}{S in D_ji(>=)}.  \eqn{S \in D_{ji}(\succ)}{S in D_ji(>)} if `strictly == TRUE`
 #' * `$winner`: name of higher scoring element. `NULL` if they are indifferent.
 #' * `$loser`: name of lower scoring element. `NULL` if they are indifferent.
-#' * `$tuples`: a list of coalitions \mjeqn{S \in 2^{N \setminus \lbrace i, j \rbrace }}{S in 2^(N - \{i,j\})} with:
-#'   * `$tuples[[x]]$coalition`: [`sets::set`], the coalition \mjseqn{S}
-#'   * `$tuples[[x]]$included`: logical, `TRUE` if \mjeqn{S \cup \lbrace i \rbrace}{Su\{i\}} and \mjeqn{S \cup \lbrace j \rbrace}{Su\{j\}} are in the power relation
-#'   * `$tuples[[x]]$winner`: name of the winning element \mjseqn{i} where \mjeqn{S \cup \lbrace i \rbrace \succ S \cup \lbrace j \rbrace}{S u \{i\} > S u \{j\}}. It is `NULL` if \mjeqn{S \cup \lbrace i \rbrace \sim S \cup \lbrace j \rbrace}{S u \{i\} ~ S u \{j\}}
-#'   * `$tuples[[x]]$e1`: index \mjseqn{x_1} at which \mjeqn{S \cup \lbrace i \rbrace \in \sum_{x_1}}{S u \{i\} in Sum_(x_1)}
-#'   * `$tuples[[x]]$e2`: index \mjseqn{x_2} at which \mjeqn{S \cup \lbrace j \rbrace \in \sum_{x_2}}{S u \{j\} in Sum_(x_2)}
+#' * `$tuples`: a list of coalitions \eqn{S \in 2^{N \setminus \lbrace i, j \rbrace }}{S in 2^(N - \{i,j\})} with:
+#'   * `$tuples[[x]]$coalition`: [`vector`][base::c()], the coalition \eqn{S}{S}
+#'   * `$tuples[[x]]$included`: logical, `TRUE` if \eqn{S \cup \lbrace i \rbrace}{Su\{i\}} and \eqn{S \cup \lbrace j \rbrace}{Su\{j\}} are in the power relation
+#'   * `$tuples[[x]]$winner`: name of the winning element \eqn{i}{i} where \eqn{S \cup \lbrace i \rbrace \succ S \cup \lbrace j \rbrace}{S u \{i\} > S u \{j\}}. It is `NULL` if \eqn{S \cup \lbrace i \rbrace \sim S \cup \lbrace j \rbrace}{S u \{i\} ~ S u \{j\}}
+#'   * `$tuples[[x]]$e1`: index \eqn{x_1}{x_1} at which \eqn{S \cup \lbrace i \rbrace \in \sum_{x_1}}{S u \{i\} in Sum_(x_1)}
+#'   * `$tuples[[x]]$e2`: index \eqn{x_2}{x_2} at which \eqn{S \cup \lbrace j \rbrace \in \sum_{x_2}}{S u \{j\} in Sum_(x_2)}
 #'
 #' The much more efficient [`cpMajorityComparisonScore()`] only calculates `$e1$score`.
 #'
@@ -42,9 +41,9 @@
 #'
 #' @template param/powerRelation
 #' @template param/e1and2
-#' @param strictly Only include \mjeqn{D_{ij}(\succ)}{D_ij(>)} and \mjeqn{D_{ji}(\succ)}{D_ji(>)}, i.e., coalitions
-#' \mjeqn{S \in 2^{N \setminus \lbrace i,j\rbrace}}{S in 2^(N-{i,j})} where
-#' \mjeqn{S \cup \lbrace i\rbrace \succ S \cup \lbrace j\rbrace}{Sui > Suj} and
+#' @param strictly Only include \eqn{D_{ij}(\succ)}{D_ij(>)} and \eqn{D_{ji}(\succ)}{D_ji(>)}, i.e., coalitions
+#' \eqn{S \in 2^{N \setminus \lbrace i,j\rbrace}}{S in 2^(N-{i,j})} where
+#' \eqn{S \cup \lbrace i\rbrace \succ S \cup \lbrace j\rbrace}{Sui > Suj} and
 #' vice versa.
 #' @template param/includeEmptySet
 #'
@@ -58,14 +57,16 @@
 #' @return `cpMajorityComparison()` returns a list with elements described in the details.
 #'
 #' @examples
-#' pr <- newPowerRelationFromString("ac > (a ~ b) > (c ~ bc)")
+#' pr <- as.PowerRelation("ac > (a ~ b) > (c ~ bc)")
 #'
+#' scores <- cpMajorityComparison(pr, "a", "b")
+#' scores
 #' # a > b
 #' # D_ab = {c, {}}
 #' # D_ba = {{}}
 #' # Score of a = 2
 #' # Score of b = 1
-#' scores <- cpMajorityComparison(pr, "a", "b")
+#'
 #' stopifnot(scores$e1$name == "a")
 #' stopifnot(scores$e2$name == "b")
 #' stopifnot(scores$e1$score == 2)
@@ -74,14 +75,14 @@
 #' stopifnot(scores$e2$score == length(scores$e2$winningCoalitions))
 #'
 #' # get tuples with coalitions S in 2^(N - \{i,j\})
-#' emptySetTuple <- Filter(function(x) x$coalition == sets::set(), scores$tuples)[[1]]
-#' playerCTuple  <- Filter(function(x) x$coalition == sets::set("c"), scores$tuples)[[1]]
+#' emptySetTuple <- Filter(function(x) identical(x$coalition, c()), scores$tuples)[[1]]
+#' playerCTuple  <- Filter(function(x) identical(x$coalition, "c"), scores$tuples)[[1]]
 #'
-#' # because {} u a ~ {} u b, there is no winner
+#' # because {}u{a} ~ {}u{b}, there is no winner
 #' stopifnot(is.null(emptySetTuple$winner))
 #' stopifnot(emptySetTuple$e1 == emptySetTuple$e2)
 #'
-#' # because c u a > c u b, player "a" gets the score
+#' # because {c}u{a} > {c}u{b}, player "a" gets the score
 #' stopifnot(playerCTuple$winner == "a")
 #' stopifnot(playerCTuple$e1 < playerCTuple$e2)
 #' stopifnot(playerCTuple$e1 == 1L)
@@ -112,7 +113,7 @@ cpMajorityComparison <- function(powerRelation, e1, e2, strictly = FALSE, includ
     winner = c(),
     loser = c()
   )
-  class(result) <- c('cpMajority', if('SingleCharElements' %in% class(powerRelation)) 'SingleCharElements')
+  class(result) <- c('cpMajority', class(powerRelation)[-1])
 
   # 2^(N-{i,j})
   coalitions <- createPowerset(setdiff(powerRelation$elements, c(e1,e2)), includeEmptySet = includeEmptySet)
@@ -120,17 +121,17 @@ cpMajorityComparison <- function(powerRelation, e1, e2, strictly = FALSE, includ
   result$tuples <- lapply(
     coalitions,
     function(S) {
-      t <- sets::tuple(
-        coalition = sets::as.set(S),
+      t <- list(
+        coalition = S,
         included = FALSE,
         winner = NULL,
         e1 = -1,
         e2 = -1
       )
 
-      eq1 <- equivalenceClassIndex(powerRelation, c(S,e1), stopIfNotExists = FALSE)
-      eq2 <- equivalenceClassIndex(powerRelation, c(S,e2), stopIfNotExists = FALSE)
-      if(eq1 >= 1 && eq2 >= 1) {
+      eq1 <- powerRelation$coalitionLookup(c(S, e1))
+      eq2 <- powerRelation$coalitionLookup(c(S, e2))
+      if(!is.null(eq1) && !is.null(eq2)) {
         t$included <- TRUE
         t$e1 <- eq1
         t$e2 <- eq2
@@ -187,7 +188,7 @@ cpMajorityComparison <- function(powerRelation, e1, e2, strictly = FALSE, includ
 #' @rdname cpMajorityComparison
 #'
 #' @return `cpMajorityComparisonScore()` returns a vector of two numbers, a positive number of coalitions where `e1` beats `e2`
-#' (\mjeqn{d_{ij}(\succeq)}{d_ij(>=)}), and a negative number of coalitions where `e1` is beaten by `e2` (\mjeqn{-d_{ji}(\succeq)}{-d_ji(>=)}).
+#' (\eqn{d_{ij}(\succeq)}{d_ij(>=)}), and a negative number of coalitions where `e1` is beaten by `e2` (\eqn{-d_{ji}(\succeq)}{-d_ji(>=)}).
 #'
 #' @examples
 #' cpMajorityComparisonScore(pr, "a", "b") # c(1,0)
@@ -210,11 +211,11 @@ cpMajorityComparisonScore <- function(powerRelation, e1, e2, strictly = FALSE, i
   neg <- 0
 
   for(S in coalitions) {
-    c1 <- equivalenceClassIndex(powerRelation, c(S, e1), FALSE)
-    if(c1 == -1) next
+    c1 <- powerRelation$coalitionLookup(c(S, e1))
+    if(is.null(c1)) next
 
-    c2 <- equivalenceClassIndex(powerRelation, c(S, e2), FALSE)
-    if(c2 == -1) next
+    c2 <- powerRelation$coalitionLookup(c(S, e2))
+    if(is.null(c2)) next
 
     if(strictly) {
       if(c1 < c2) pos <- pos + 1
@@ -271,5 +272,6 @@ print.cpMajority <- function(x, ...) {
   pCoalitions(x$e2$winningCoalitions)
   cat('}')
   cat('\nScore of', x$e1$name, '=', x$e1$score)
-  cat('\nScore of', x$e2$name, '=', x$e2$score, '\n')
+  cat('\nScore of', x$e2$name, '=', x$e2$score)
+  cat('\n')
 }
